gatenlp.processing.matcher API documentation
Description: Module that defines classes for matchers other than gazetteers which match e.g. regular expressions of strings or annotations.

# Module `gatenlp.processing.matcher`

Module that defines classes for matchers other than gazetteers which match e.g. regular expressions of strings or annotations.

Expand source code

    """
    Module that defines classes for matchers other than gazetteers which match e.g. regular expressions
    of strings or annotations.
    """

    class StringRegexMatcher:
        """
        NOT YET IMPLEMENTED
        """

        pass

    # class AnnotationRegexMatcher:
    #    """ """
    #    pass

## Classes

`class StringRegexMatcher`

  NOT YET IMPLEMENTED

  Expand source code

      class StringRegexMatcher:
          """
          NOT YET IMPLEMENTED
          """

          pass